@@ -766,7 +766,12 @@ my $get_ec2_api=sub {
    computing operation. Please choose one:
 
 END
-   my $dirtree=Net::FullAuto::FA_Core::get_isets('Amazon');
+   my $dirtree='';
+   if ($_[0]) {
+      $dirtree=Net::FullAuto::FA_Core::get_isets($_[0]);
+   } else {
+      $dirtree=Net::FullAuto::FA_Core::get_isets('Amazon');
+   }
    my %choose_demo_setup=(
 
       Name => 'choose_demo_setup',
@@ -1049,6 +1054,7 @@ sub new_user_amazon {
 
    my $identity_file=$_[0]||'';
    my $cleanup=$_[3]||'';
+   my $iset_amazon=$_[4]||'';
    unless ($cleanup) {
       print $Net::FullAuto::FA_Core::fa_welcome;
       sleep 3;
@@ -1234,16 +1240,25 @@ sub new_user_amazon {
    FullAuto will now check the current system to determine if the ec2 API
    is installed and available for use.
 END
+   if ($iset_amazon) {
+      open(FH,"<$iset_amazon") || do {
+         print "   FATAL ERROR!: Cannot open Amazon Instruction Set ".
+               "\"$iset_amazon\"\n                 $!\n";
+         Net::FullAuto::FA_Core::cleanup(); 
+      };
+      close FH;
+      Net::FullAuto::FA_Core::Menu($get_ec2_api->($iset_amazon));
+   } else {
+      my %welcome_fa_amazon=(
 
-   my %welcome_fa_amazon=(
+         Name   => 'welcome_fa_amazon',
+         Banner => $banner,
+         Result => $get_ec2_api,
 
-      Name   => 'welcome_fa_amazon',
-      Banner => $banner,
-      Result => $get_ec2_api,
-
-   );
-   Net::FullAuto::FA_Core::Menu(\%welcome_fa_amazon);
-   Net::FullAuto::FA_Core::cleanup();
+      );
+      Net::FullAuto::FA_Core::Menu(\%welcome_fa_amazon);
+      Net::FullAuto::FA_Core::cleanup();
+   }
 
 }
 
